]> sigrok.org Git - libsigrok.git/blobdiff - device.c
sr: Fix some TODOs, improve comments/docs.
[libsigrok.git] / device.c
index c4ff6ebe4f0d92ab0e47ee5f9949c77527fbc64f..3166ea8e0c087d72431ab7269d80e0308109c2cf 100644 (file)
--- a/device.c
+++ b/device.c
@@ -55,7 +55,7 @@ static GSList *devs = NULL;
  * TODO: Error checks?
  * TODO: Option to only scan for specific devices or device classes.
  *
* @return SR_OK upon success, SR_ERR upon errors.
  */
 SR_API int sr_dev_scan(void)
 {
@@ -65,7 +65,7 @@ SR_API int sr_dev_scan(void)
        drivers = sr_driver_list();
        if (!drivers[0]) {
                sr_err("dev: %s: no supported hardware drivers", __func__);
-               return SR_ERR; /* TODO: More specific error? */
+               return SR_ERR_BUG;
        }
 
        /*
@@ -55,7 +55,7 @@ static GSList *devs = NULL;
  * TODO: Option to only scan for specific devices or device classes.
  *
- * @return SR_OK upon success, SR_ERR upon errors.
+ * @return SR_OK upon success, SR_ERR_BUG upon internal errors.
  */
 SR_API int sr_dev_scan(void)